@@ -67,10 +67,7 @@ KTNEFWriter::KTNEFWriter()
     addProperty(attOEMCODEPAGE, atpBYTE, list);
 }
 
-KTNEFWriter::~KTNEFWriter()
-{
-    delete d;
-}
+KTNEFWriter::~KTNEFWriter() = default;
 
 void KTNEFWriter::addProperty(int tag, int type, const QVariant &value)
 {
@@ -127,7 +124,8 @@ bool KTNEFWriter::writeProperty(QDataStream &stream, int &bytes, int tag) const
     quint32 i;
     quint16 checksum = 0;
     QList<QVariant> list;
-    QByteArray cs, cs2;
+    QByteArray cs;
+    QByteArray cs2;
     QDateTime dt;
     QDate date;
     QTime time;
